@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Jean-Pierre Gattuso and Héloïse Lavigne and Aurélien Proye
+# Copyright (C) 2008 Jean-Pierre Gattuso and Heloise Lavigne and Aurelien Proye
 #
 # This file is part of seacarb.
 #
@@ -52,6 +52,12 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 	lnKb = tmp1 / TK + tmp2 + tmp3 + 0.053105*sqrt(S)*TK;
 	Kb <- exp(lnKb)
 
+	# ---- Conversion from Total scale to seawater scale before pressure corrections
+
+	factor <- kconv(S=S, T=T, P=rep(0,nK))$ktotal2SWS
+
+	Kb <- Kb * factor
+
 	# ------------------- Pression effect --------------------------------
 		for(i in (1:nK)){		
 
@@ -105,9 +111,9 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 factor <- rep(NA,nK)
 pHsc <- rep(NA,nK)
 for(i in (1:nK)){   
- if(pHscale[i]=="T"){factor[i] <- 1 ; pHsc[i] <- "total scale"}
- if(pHscale[i]=="F"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2free ; pHsc[i] <- "free scale"}
- if(pHscale[i]=="SWS"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2SWS ; pHsc[i] <- "seawater scale"}
+ if(pHscale[i]=="T"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$kSWS2total ; pHsc[i] <- "total scale"}
+ if(pHscale[i]=="F"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$kSWS2free ; pHsc[i] <- "free scale"}
+ if(pHscale[i]=="SWS"){factor[i] <- 1 ; pHsc[i] <- "seawater scale"}
 Kb[i] <- Kb[i]*factor[i]
 }
 
